@@ -27,14 +27,14 @@
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns `terms`
 #' (the selectors or variables selected), `original` (the original levels) and
 #' `value` (the cleaned levels) is returned.
-#' 
+#'
 #' @template case-weights-not-supported
 #'
 #' @seealso [step_clean_names()], [recipes::step_factor2string()],
 #'   [recipes::step_string2factor()], [recipes::step_regex()],
 #'   [recipes::step_unknown()], [recipes::step_novel()], [recipes::step_other()]
 #' @family Steps for Text Cleaning
-#'   
+#'
 #' @examplesIf rlang::is_installed("janitor")
 #' library(recipes)
 #' library(modeldata)
@@ -93,7 +93,8 @@ step_clean_levels_new <-
 #' @export
 prep.step_clean_levels <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names], quant = FALSE)
+
+  check_type(training[, col_names], types = c("string", "factor", "ordered"))
 
   if (length(col_names) > 0) {
     orig <- purrr::map(training[, col_names], levels)
@@ -165,4 +166,4 @@ tidy.step_clean_levels <- function(x, ...) {
 #' @export
 required_pkgs.step_clean_levels <- function(x, ...) {
   c("textrecipes", "janitor")
-}
\ No newline at end of file
+}
