@@ -9,8 +9,10 @@ library(textrecipes)
 library(tokenizers)
 
 ## -----------------------------------------------------------------------------
-abc <- c("The Bank is a place where you put your money;",
-         "The Bee is an insect that gathers honey.")
+abc <- c(
+  "The Bank is a place where you put your money;",
+  "The Bee is an insect that gathers honey."
+)
 
 tokenize_words(abc)
 
@@ -28,7 +30,7 @@ tokenize_ngrams(abc, n = 3, ngram_delim = "_")
 ## -----------------------------------------------------------------------------
 abc_tibble <- tibble(text = abc)
 
-rec <- recipe(~ text, data = abc_tibble) %>%
+rec <- recipe(~text, data = abc_tibble) %>%
   step_tokenize(text, token = "ngrams") %>%
   step_tokenfilter(text) %>%
   step_tf(text)
@@ -44,9 +46,11 @@ names(abc_ngram)
 ## -----------------------------------------------------------------------------
 abc_tibble <- tibble(text = abc)
 
-rec <- recipe(~ text, data = abc_tibble) %>%
-  step_tokenize(text, token = "ngrams", options = list(n = 2, 
-                                                       ngram_delim = "_")) %>%
+rec <- recipe(~text, data = abc_tibble) %>%
+  step_tokenize(text, token = "ngrams", options = list(
+    n = 2,
+    ngram_delim = "_"
+  )) %>%
   step_tokenfilter(text) %>%
   step_tf(text)
 
@@ -65,7 +69,7 @@ bigram <- function(x) {
   tokenizers::tokenize_ngrams(x, lowercase = FALSE, n = 2, ngram_delim = ".")
 }
 
-rec <- recipe(~ text, data = abc_tibble) %>%
+rec <- recipe(~text, data = abc_tibble) %>%
   step_tokenize(text, custom_token = bigram) %>%
   step_tokenfilter(text) %>%
   step_tf(text)
@@ -81,7 +85,7 @@ names(abc_ngram)
 ## -----------------------------------------------------------------------------
 abc_tibble <- tibble(text = abc)
 
-rec <- recipe(~ text, data = abc_tibble) %>%
+rec <- recipe(~text, data = abc_tibble) %>%
   step_tokenize(text) %>%
   step_ngram(text, num_tokens = 3) %>%
   step_tokenfilter(text) %>%
@@ -98,7 +102,7 @@ names(abc_ngram)
 ## -----------------------------------------------------------------------------
 abc_tibble <- tibble(text = abc)
 
-rec <- recipe(~ text, data = abc_tibble) %>%
+rec <- recipe(~text, data = abc_tibble) %>%
   step_tokenize(text) %>%
   step_stem(text) %>%
   step_ngram(text, num_tokens = 3) %>%
