@@ -1,4 +1,3 @@
-
 test_data <- list(
   c("not", "eat", "them", "here", "or", "there."),
   c("not", "eat", "them", "anywhere.")
@@ -26,16 +25,17 @@ test_that("ngram works with varrying number of `n`", {
     )
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     cpp11_ngram(test_data, n = 0L, n_min = 0L, delim = "_")
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     cpp11_ngram(test_data, n = -1L, n_min = -1L, delim = "_")
   )
 })
 
-
 test_that("tokenlist_ngram works with n_min and n", {
   tknlist <- list(
     c("a", "b", "c", "d", "e"),
@@ -100,7 +100,6 @@ test_that("tokenlist_ngram works with n_min and n", {
   )
 })
 
-
 test_that("ngram works with delim", {
   expect_equal(
     cpp11_ngram(test_data, n = 3L, n_min = 3L, delim = ""),
@@ -136,7 +135,6 @@ test_that("ngram returns length zero vectors when length(x) < n", {
   )
 })
 
-
 library(recipes)
 library(textrecipes)
 
@@ -242,17 +240,19 @@ test_that("bake method errors when needed non-standard role columns are missing"
     step_tokenize(text) %>%
     prep() %>%
     bake(new_data = NULL)
-  
+
   rec <- recipe(tokenized_test_data) %>%
     update_role(text, new_role = "predictor") %>%
     step_ngram(text) %>%
     update_role(text, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   trained <- prep(rec, training = tokenized_test_data, verbose = FALSE)
-  
-  expect_error(bake(trained, new_data = tokenized_test_data[, -1]),
-               class = "new_data_missing_column")
+
+  expect_error(
+    bake(trained, new_data = tokenized_test_data[, -1]),
+    class = "new_data_missing_column"
+  )
 })
 
 test_that("printing", {
@@ -303,3 +303,31 @@ test_that("empty printing", {
 
   expect_snapshot(rec)
 })
+
+test_that("tunable", {
+  rec <-
+    recipe(~., data = mtcars) %>%
+    step_ngram(all_predictors())
+  rec_param <- tunable.step_ngram(rec$steps[[1]])
+  expect_equal(rec_param$name, c("num_tokens"))
+  expect_true(all(rec_param$source == "recipe"))
+  expect_true(is.list(rec_param$call_info))
+  expect_equal(nrow(rec_param), 1)
+  expect_equal(
+    names(rec_param),
+    c("name", "call_info", "source", "component", "component_id")
+  )
+})
+
+test_that("tunable is setup to works with extract_parameter_set_dials works", {
+  rec <- recipe(~., data = mtcars) %>%
+    step_ngram(
+      all_predictors(),
+      num_tokens = hardhat::tune()
+    )
+  
+  params <- extract_parameter_set_dials(rec)
+  
+  expect_s3_class(params, "parameters")
+  expect_identical(nrow(params), 1L)
+})
\ No newline at end of file
