@@ -23,11 +23,13 @@ test_that("bake method errors when needed non-standard role columns are missing"
     step_text_normalization(text) %>%
     update_role(text, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   trained <- prep(rec, training = ex_dat, verbose = FALSE)
-  
-  expect_error(bake(trained, new_data = ex_dat[, -1]),
-               class = "new_data_missing_column")
+
+  expect_error(
+    bake(trained, new_data = ex_dat[, -1]),
+    class = "new_data_missing_column"
+  )
 })
 
 test_that("printing", {
