@@ -62,7 +62,6 @@ test_that("step_tf works with vocabulary argument", {
   )
 })
 
-
 test_that("step_tf works with other weighting schemes", {
   rec <- rec %>%
     step_tokenize(text) %>%
@@ -120,17 +119,33 @@ test_that("bake method errors when needed non-standard role columns are missing"
     step_tokenize(text) %>%
     prep() %>%
     bake(new_data = NULL)
-  
+
   rec <- recipe(tokenized_test_data) %>%
     update_role(text, new_role = "predictor") %>%
     step_tf(text) %>%
     update_role(text, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   trained <- prep(rec, training = tokenized_test_data, verbose = FALSE)
+
+  expect_error(
+    bake(trained, new_data = tokenized_test_data[, -1]),
+    class = "new_data_missing_column"
+  )
+})
+
+test_that("check_name() is used", {
+  dat <- test_data
+  dat$tf_text_i <- dat$text
   
-  expect_error(bake(trained, new_data = tokenized_test_data[, -1]),
-               class = "new_data_missing_column")
+  rec <- recipe(~., data = dat) %>%
+    step_tokenize(text) %>%
+    step_tf(text)
+  
+  expect_snapshot(
+    error = TRUE,
+    prep(rec, training = dat)
+  )
 })
 
 test_that("printing", {
@@ -145,16 +160,17 @@ test_that("keep_original_cols works", {
   koc_rec <- rec %>%
     step_tokenize(text) %>%
     step_tf(text, keep_original_cols = TRUE)
-  
+
   koc_trained <- prep(koc_rec, training = test_data, verbose = FALSE)
-  
+
   koc_pred <- bake(koc_trained, new_data = test_data, all_predictors())
-  
+
   expect_identical(
     colnames(koc_pred),
-    c("text", "tf_text_am", "tf_text_and", "tf_text_anywhere", "tf_text_do", 
-      "tf_text_eat", "tf_text_eggs", "tf_text_green", "tf_text_ham", 
-      "tf_text_here", "tf_text_i", "tf_text_like", "tf_text_not", "tf_text_or", 
+    c(
+      "text", "tf_text_am", "tf_text_and", "tf_text_anywhere", "tf_text_do",
+      "tf_text_eat", "tf_text_eggs", "tf_text_green", "tf_text_ham",
+      "tf_text_here", "tf_text_i", "tf_text_like", "tf_text_not", "tf_text_or",
       "tf_text_sam", "tf_text_them", "tf_text_there", "tf_text_would"
     )
   )
@@ -164,20 +180,19 @@ test_that("can prep recipes with no keep_original_cols", {
   koc_rec <- rec %>%
     step_tokenize(text) %>%
     step_tf(text, keep_original_cols = TRUE)
-  
+
   koc_rec$steps[[2]]$keep_original_cols <- NULL
-  
+
   expect_snapshot(
     koc_trained <- prep(koc_rec, training = test_data, verbose = FALSE)
   )
-  
+
   expect_error(
     pca_pred <- bake(koc_trained, new_data = test_data, all_predictors()),
     NA
   )
 })
 
-
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_tf(rec1)
@@ -218,3 +233,32 @@ test_that("empty printing", {
 
   expect_snapshot(rec)
 })
+
+test_that("tunable", {
+  rec <-
+    recipe(~., data = mtcars) %>%
+    step_tf(all_predictors())
+  rec_param <- tunable.step_tf(rec$steps[[1]])
+  expect_equal(rec_param$name, c("weight_scheme", "weight"))
+  expect_true(all(rec_param$source == "recipe"))
+  expect_true(is.list(rec_param$call_info))
+  expect_equal(nrow(rec_param), 2)
+  expect_equal(
+    names(rec_param),
+    c("name", "call_info", "source", "component", "component_id")
+  )
+})
+
+test_that("tunable is setup to works with extract_parameter_set_dials works", {
+  rec <- recipe(~., data = mtcars) %>%
+    step_tf(
+      all_predictors(),
+      weight_scheme = hardhat::tune(),
+      weight = hardhat::tune()
+    )
+  
+  params <- extract_parameter_set_dials(rec)
+  
+  expect_s3_class(params, "parameters")
+  expect_identical(nrow(params), 2L)
+})
\ No newline at end of file
