@@ -42,7 +42,8 @@ test_that("tokenization is done correctly", {
 })
 
 test_that("step throws an error if unavaliable tokenizer is picked", {
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_tokenize(text, token = "wrong") %>%
       prep()
@@ -91,7 +92,8 @@ test_that("arguments are passed using options argument", {
 })
 
 test_that("tokenization errors with wrong engines", {
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_tokenize(text, engine = "fake") %>%
       prep()
@@ -129,11 +131,13 @@ test_that("bake method errors when needed non-standard role columns are missing"
     step_tokenize(text) %>%
     update_role(text, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   trained <- prep(rec, training = test_data, verbose = FALSE)
-  
-  expect_error(bake(trained, new_data = test_data[, -1]),
-               class = "new_data_missing_column")
+
+  expect_error(
+    bake(trained, new_data = test_data[, -1]),
+    class = "new_data_missing_column"
+  )
 })
 
 test_that("printing", {
@@ -183,3 +187,31 @@ test_that("empty printing", {
 
   expect_snapshot(rec)
 })
+
+test_that("tunable", {
+  rec <-
+    recipe(~., data = mtcars) %>%
+    step_tokenize(all_predictors())
+  rec_param <- tunable.step_tokenize(rec$steps[[1]])
+  expect_equal(rec_param$name, c("token"))
+  expect_true(all(rec_param$source == "recipe"))
+  expect_true(is.list(rec_param$call_info))
+  expect_equal(nrow(rec_param), 1)
+  expect_equal(
+    names(rec_param),
+    c("name", "call_info", "source", "component", "component_id")
+  )
+})
+
+test_that("tunable is setup to works with extract_parameter_set_dials works", {
+  rec <- recipe(~., data = mtcars) %>%
+    step_tokenize(
+      all_predictors(),
+      token = hardhat::tune()
+    )
+  
+  params <- extract_parameter_set_dials(rec)
+  
+  expect_s3_class(params, "parameters")
+  expect_identical(nrow(params), 1L)
+})
\ No newline at end of file
