@@ -109,25 +109,30 @@ test_that("tokenlist creation works", {
 })
 
 test_that("tokenlist errors with diffent length input", {
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist(list(letters), lemma = list(letters, letters))
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist(list(letters), pos = list(letters, letters))
   )
 })
 
 test_that("new_tokenlist errors with wrong input", {
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     new_tokenlist(letters)
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     new_tokenlist(list(letters), lemma = letters)
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     new_tokenlist(list(letters), pos = letters)
   )
 })
@@ -200,7 +205,6 @@ test_that("tokenlist_filter works", {
     tokenlist(list(character(), character()))
   )
 
-
   expect_equal(
     tokenlist_filter(tkn_list, letters[1:10], keep = TRUE),
     tokenlist(list(letters[1:10], character()))
@@ -216,7 +220,8 @@ test_that("tokenlist_filter works", {
     tkn_list
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_filter(LETTERS, letters)
   )
 })
@@ -295,11 +300,13 @@ test_that("tokenlist_apply works", {
     tokenlist(list(character(), character(), "D"))
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_apply(tkn_list, letter_filter, let = "D")
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_apply(letters, toupper)
   )
 })
@@ -346,11 +353,13 @@ test_that("tokenlist_to_dtm works", {
     )
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_to_dtm(tkn_list)
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_to_dtm(letters)
   )
 })
@@ -369,11 +378,13 @@ test_that("tokenlist_lemma works", {
     )
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_lemma(letters)
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_lemma(tokenlist(list(letters)))
   )
 })
@@ -417,10 +428,12 @@ test_that("tokenlist_pos_filter works", {
     tokenlist(list(letters[1:2]), list(letters[1:2]), list(letters[1:2]))
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_pos_filter(letters, "NOUN")
   )
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_pos_filter(tokenlist(data), "NOUN")
   )
 })
@@ -439,7 +452,6 @@ test_that("tokenlist_ngram works", {
 
   expect_s3_class(ngrams, "textrecipes_tokenlist")
 
-
   expect_equal(
     vctrs::field(ngrams, "tokens"),
     list(
@@ -520,7 +532,8 @@ test_that("tokenlist_ngram works with n_min and n", {
 })
 
 test_that("tokenlist_ngram errors", {
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_ngram(letters)
   )
 
@@ -530,15 +543,18 @@ test_that("tokenlist_ngram errors", {
     character(0)
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_ngram(tokenlist(data), 0, 3, " ")
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_ngram(tokenlist(data), 3, 0, " ")
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     tokenlist_ngram(tokenlist(data), 1, 2, " ")
   )
 })
